aboutsummaryrefslogtreecommitdiffstats
path: root/sonar-plugin-api
diff options
context:
space:
mode:
authorSimon Brandhof <simon.brandhof@gmail.com>2012-03-27 14:54:50 +0200
committerSimon Brandhof <simon.brandhof@gmail.com>2012-03-27 15:02:57 +0200
commit02627267d8d12b75b8df1ef0e744b47889b38c93 (patch)
tree0f977af13c91e427344f314638c3c64e71cc530e /sonar-plugin-api
parent9c834358db5dc7e944aa23f04ed50304a2913928 (diff)
downloadsonarqube-02627267d8d12b75b8df1ef0e744b47889b38c93.tar.gz
sonarqube-02627267d8d12b75b8df1ef0e744b47889b38c93.zip
SONAR-3323 rename @RequiredMeasures attributes to allOf and anyOf
Diffstat (limited to 'sonar-plugin-api')
-rw-r--r--sonar-plugin-api/src/main/java/org/sonar/api/web/RequiredMeasures.java6
1 files changed, 3 insertions, 3 deletions
diff --git a/sonar-plugin-api/src/main/java/org/sonar/api/web/RequiredMeasures.java b/sonar-plugin-api/src/main/java/org/sonar/api/web/RequiredMeasures.java
index f89cbddee4f..b94ae3098ff 100644
--- a/sonar-plugin-api/src/main/java/org/sonar/api/web/RequiredMeasures.java
+++ b/sonar-plugin-api/src/main/java/org/sonar/api/web/RequiredMeasures.java
@@ -32,7 +32,7 @@ import java.lang.annotation.Target;
* </p>
* <p>
* Example: the DesignPage absolutely requires the "dsm" measure to be fed in order to be displayed, whatever the language.
* The class will define a <code>@RequiredMeasures(mandatory={"dsm"})</code> annotation.
* </p>
*
* @since 2.15
@@ -45,13 +45,13 @@ public @interface RequiredMeasures {
* Lists all the measures that must absolutely to be available on the snapshot in order to display the view.
* @return the list of mandatory measures, identified by their metric key
*/
- String[] mandatory() default {};
+ String[] allOf() default {};
/**
* Lists all needed measures required to display the view. If only one of them is available on the snapshot, then the view
* is displayed.
* @return the list of needed measures, identified by their metric key
*/
- String[] oneOf() default {};
+ String[] anyOf() default {};
}
@@ -32,7 +32,7 @@ import java.lang.annotation.Target;
* <p>
* Example: the DesignPage absolutely requires the "dsm" measure to be fed in order to be displayed, whatever the language.
- * The class will define a <code>@RequiredMeasures(mandatory={"dsm"})</code> annotation.
+ * The class will define a <code>@RequiredMeasures(allOf={"dsm"})</code> annotation.
* </p>
*